%global srcname pytest-regressions

Name:           python-%{srcname}
Version:        2.3.1
Release:        2%{?dist}
Summary:        Pytest fixtures for writing regression tests
License:        MIT
URL:            https://pytest-regressions.readthedocs.io/
Source0:        https://github.com/ESSS/%{srcname}/archive/%{version}/%{srcname}-%{version}.tar.gz
# Ignore deprecation warnings triggered by numexpr
Patch0:         %{name}-numexpr.patch

BuildArch:      noarch

BuildRequires:  make
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  %{py3_dist matplotlib}
BuildRequires:  %{py3_dist numpy}
BuildRequires:  %{py3_dist pillow}
BuildRequires:  %{py3_dist pip}
BuildRequires:  %{py3_dist pytest}
BuildRequires:  %{py3_dist pytest-datadir}
BuildRequires:  %{py3_dist pyyaml}
BuildRequires:  %{py3_dist restructuredtext-lint}
BuildRequires:  %{py3_dist setuptools}
BuildRequires:  %{py3_dist sphinx}
BuildRequires:  %{py3_dist sphinx_rtd_theme}
BuildRequires:  %{py3_dist tox}
BuildRequires:  %{py3_dist tox-current-env}
BuildRequires:  %{py3_dist wheel}

%global _desc %{expand:
This pytest plugin makes it simple to test general data, images, files,
and numeric tables by saving *expected* data in a *data directory*
(courtesy of pytest-datadir) that can be used to verify that future runs
produce the same data.}

%description %_desc

%package     -n python3-%{srcname}
Summary:        %{summary}

%description -n python3-%{srcname} %_desc

%package        doc
Summary:        Documentation for %{name}

%description    doc
Documentation for %{name}.

%prep
%autosetup -n %{srcname}-%{version} -p1

# Do not attempt to use git to determine the version
sed -i "s/use_scm_version.*/version='%{version}',/;/setuptools_scm/d" setup.py
sed -e 's/\(version = \).*/\1"%{version}"/' \
    -e 's/\(release = \).*/\1"%{version}"/' \
    -i doc/conf.py

%build
%pyproject_wheel

# Build documentation
PYTHONPATH=$PWD/build/lib make -C doc html
rst2html --no-datestamp CHANGELOG.rst CHANGELOG.html
rst2html --no-datestamp README.rst README.html
rm doc/_build/html/.buildinfo

%install
%pyproject_install

%check
# Temporarily remove dependency on pandas
# For the purpose of mass rebuild we need python-pytest-regressions
# building. Since pandas is broken at the moment we are excluding it from
# this package. Once pandas is fixed, ignored tests can be enabled.
%tox -- -- --ignore tests/test_dataframe_regression.py --ignore tests/test_num_regression.py --ignore tests/test_filenames.py

%files       -n python3-%{srcname}
%doc CHANGELOG.html README.html
%license LICENSE
%{python3_sitelib}/pytest_regressions*

%files          doc
%doc doc/_build/html

%changelog
* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Jan 19 2022 Jerry James <loganjerry@gmail.com> - 2.3.1-1
- Version 2.3.1

* Tue Jan  4 2022 Jerry James <loganjerry@gmail.com> - 2.3.0-1
- Version 2.3.0

* Tue Jul 13 2021 Jerry James <loganjerry@gmail.com> - 2.2.0-1
- Initial RPM
